from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.sherpa_job_bean import SherpaJobBean


T = TypeVar("T", bound="ProjectStatus")


@_attrs_define
class ProjectStatus:
    """
    Attributes:
        project_name (str):
        status (str):
        pending_job (Union[Unset, SherpaJobBean]):
    """

    project_name: str
    status: str
    pending_job: Union[Unset, "SherpaJobBean"] = UNSET

    def to_dict(self) -> dict[str, Any]:
        project_name = self.project_name

        status = self.status

        pending_job: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.pending_job, Unset):
            pending_job = self.pending_job.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "projectName": project_name,
                "status": status,
            }
        )
        if pending_job is not UNSET:
            field_dict["pendingJob"] = pending_job

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.sherpa_job_bean import SherpaJobBean

        d = dict(src_dict)
        project_name = d.pop("projectName")

        status = d.pop("status")

        _pending_job = d.pop("pendingJob", UNSET)
        pending_job: Union[Unset, SherpaJobBean]
        if isinstance(_pending_job, Unset):
            pending_job = UNSET
        else:
            pending_job = SherpaJobBean.from_dict(_pending_job)

        project_status = cls(
            project_name=project_name,
            status=status,
            pending_job=pending_job,
        )

        return project_status



from http import HTTPStatus
from io import BytesIO
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.format_binary_form import FormatBinaryForm
from ...types import UNSET, File, Response, Unset


def _get_kwargs(
    *,
    body: FormatBinaryForm,
    inline_labels: Union[Unset, bool] = True,
    inline_label_ids: Union[Unset, bool] = True,
    inline_text: Union[Unset, bool] = True,
    debug: Union[Unset, bool] = False,
    parallelize: Union[Unset, bool] = False,
    error_policy: Union[Unset, str] = UNSET,
    project_context: Union[Unset, str] = UNSET,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    params: dict[str, Any] = {}

    params["inlineLabels"] = inline_labels

    params["inlineLabelIds"] = inline_label_ids

    params["inlineText"] = inline_text

    params["debug"] = debug

    params["parallelize"] = parallelize

    params["errorPolicy"] = error_policy

    params["projectContext"] = project_context

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": "/annotate/_annotate_format_binary",
        "params": params,
    }

    _body = body.to_multipart()

    _kwargs["files"] = _body

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[File]:
    if response.status_code == 200:
        response_200 = File(payload=BytesIO(response.json()))

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[File]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: FormatBinaryForm,
    inline_labels: Union[Unset, bool] = True,
    inline_label_ids: Union[Unset, bool] = True,
    inline_text: Union[Unset, bool] = True,
    debug: Union[Unset, bool] = False,
    parallelize: Union[Unset, bool] = False,
    error_policy: Union[Unset, str] = UNSET,
    project_context: Union[Unset, str] = UNSET,
) -> Response[File]:
    """annotate a binary document with a pipeline and return a formatted result

    Args:
        inline_labels (Union[Unset, bool]):  Default: True.
        inline_label_ids (Union[Unset, bool]):  Default: True.
        inline_text (Union[Unset, bool]):  Default: True.
        debug (Union[Unset, bool]):  Default: False.
        parallelize (Union[Unset, bool]):  Default: False.
        error_policy (Union[Unset, str]):
        project_context (Union[Unset, str]):
        body (FormatBinaryForm):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[File]
    """

    kwargs = _get_kwargs(
        body=body,
        inline_labels=inline_labels,
        inline_label_ids=inline_label_ids,
        inline_text=inline_text,
        debug=debug,
        parallelize=parallelize,
        error_policy=error_policy,
        project_context=project_context,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    body: FormatBinaryForm,
    inline_labels: Union[Unset, bool] = True,
    inline_label_ids: Union[Unset, bool] = True,
    inline_text: Union[Unset, bool] = True,
    debug: Union[Unset, bool] = False,
    parallelize: Union[Unset, bool] = False,
    error_policy: Union[Unset, str] = UNSET,
    project_context: Union[Unset, str] = UNSET,
) -> Optional[File]:
    """annotate a binary document with a pipeline and return a formatted result

    Args:
        inline_labels (Union[Unset, bool]):  Default: True.
        inline_label_ids (Union[Unset, bool]):  Default: True.
        inline_text (Union[Unset, bool]):  Default: True.
        debug (Union[Unset, bool]):  Default: False.
        parallelize (Union[Unset, bool]):  Default: False.
        error_policy (Union[Unset, str]):
        project_context (Union[Unset, str]):
        body (FormatBinaryForm):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        File
    """

    return sync_detailed(
        client=client,
        body=body,
        inline_labels=inline_labels,
        inline_label_ids=inline_label_ids,
        inline_text=inline_text,
        debug=debug,
        parallelize=parallelize,
        error_policy=error_policy,
        project_context=project_context,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: FormatBinaryForm,
    inline_labels: Union[Unset, bool] = True,
    inline_label_ids: Union[Unset, bool] = True,
    inline_text: Union[Unset, bool] = True,
    debug: Union[Unset, bool] = False,
    parallelize: Union[Unset, bool] = False,
    error_policy: Union[Unset, str] = UNSET,
    project_context: Union[Unset, str] = UNSET,
) -> Response[File]:
    """annotate a binary document with a pipeline and return a formatted result

    Args:
        inline_labels (Union[Unset, bool]):  Default: True.
        inline_label_ids (Union[Unset, bool]):  Default: True.
        inline_text (Union[Unset, bool]):  Default: True.
        debug (Union[Unset, bool]):  Default: False.
        parallelize (Union[Unset, bool]):  Default: False.
        error_policy (Union[Unset, str]):
        project_context (Union[Unset, str]):
        body (FormatBinaryForm):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[File]
    """

    kwargs = _get_kwargs(
        body=body,
        inline_labels=inline_labels,
        inline_label_ids=inline_label_ids,
        inline_text=inline_text,
        debug=debug,
        parallelize=parallelize,
        error_policy=error_policy,
        project_context=project_context,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    body: FormatBinaryForm,
    inline_labels: Union[Unset, bool] = True,
    inline_label_ids: Union[Unset, bool] = True,
    inline_text: Union[Unset, bool] = True,
    debug: Union[Unset, bool] = False,
    parallelize: Union[Unset, bool] = False,
    error_policy: Union[Unset, str] = UNSET,
    project_context: Union[Unset, str] = UNSET,
) -> Optional[File]:
    """annotate a binary document with a pipeline and return a formatted result

    Args:
        inline_labels (Union[Unset, bool]):  Default: True.
        inline_label_ids (Union[Unset, bool]):  Default: True.
        inline_text (Union[Unset, bool]):  Default: True.
        debug (Union[Unset, bool]):  Default: False.
        parallelize (Union[Unset, bool]):  Default: False.
        error_policy (Union[Unset, str]):
        project_context (Union[Unset, str]):
        body (FormatBinaryForm):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        File
    """

    return (
        await asyncio_detailed(
            client=client,
            body=body,
            inline_labels=inline_labels,
            inline_label_ids=inline_label_ids,
            inline_text=inline_text,
            debug=debug,
            parallelize=parallelize,
            error_policy=error_policy,
            project_context=project_context,
        )
    ).parsed



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="UserPermissionsUpdate")


@_attrs_define
class UserPermissionsUpdate:
    """
    Attributes:
        disabled (Union[Unset, bool]):
        permissions (Union[Unset, list[str]]):
        roles (Union[Unset, list[str]]):
    """

    disabled: Union[Unset, bool] = UNSET
    permissions: Union[Unset, list[str]] = UNSET
    roles: Union[Unset, list[str]] = UNSET

    def to_dict(self) -> dict[str, Any]:
        disabled = self.disabled

        permissions: Union[Unset, list[str]] = UNSET
        if not isinstance(self.permissions, Unset):
            permissions = self.permissions

        roles: Union[Unset, list[str]] = UNSET
        if not isinstance(self.roles, Unset):
            roles = self.roles

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if disabled is not UNSET:
            field_dict["disabled"] = disabled
        if permissions is not UNSET:
            field_dict["permissions"] = permissions
        if roles is not UNSET:
            field_dict["roles"] = roles

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        disabled = d.pop("disabled", UNSET)

        permissions = cast(list[str], d.pop("permissions", UNSET))

        roles = cast(list[str], d.pop("roles", UNSET))

        user_permissions_update = cls(
            disabled=disabled,
            permissions=permissions,
            roles=roles,
        )

        return user_permissions_update



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define

T = TypeVar("T", bound="UserGroupRef")


@_attrs_define
class UserGroupRef:
    """
    Attributes:
        group_name (str):
        username (str):
    """

    group_name: str
    username: str

    def to_dict(self) -> dict[str, Any]:
        group_name = self.group_name

        username = self.username

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "groupName": group_name,
                "username": username,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        group_name = d.pop("groupName")

        username = d.pop("username")

        user_group_ref = cls(
            group_name=group_name,
            username=username,
        )

        return user_group_ref



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define

if TYPE_CHECKING:
    from ..models.user_share import UserShare


T = TypeVar("T", bound="ProjectUserShare")


@_attrs_define
class ProjectUserShare:
    """
    Attributes:
        project_name (str):
        share (UserShare):
    """

    project_name: str
    share: "UserShare"

    def to_dict(self) -> dict[str, Any]:
        project_name = self.project_name

        share = self.share.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "projectName": project_name,
                "share": share,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.user_share import UserShare

        d = dict(src_dict)
        project_name = d.pop("projectName")

        share = UserShare.from_dict(d.pop("share"))

        project_user_share = cls(
            project_name=project_name,
            share=share,
        )

        return project_user_share



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.signin_card_main_titles import SigninCardMainTitles
    from ..models.signin_card_subtitles import SigninCardSubtitles


T = TypeVar("T", bound="SigninCardForm")


@_attrs_define
class SigninCardForm:
    """Form on signin page

    Attributes:
        btn_color (Union[Unset, str]):
        btn_text_color (Union[Unset, str]):
        card_bg_color (Union[Unset, str]):
        card_border_color (Union[Unset, str]):
        card_dark_mode (Union[Unset, bool]):  Default: False.
        card_opacity (Union[Unset, float]):  Default: 1.0.
        main_title (Union[Unset, SigninCardMainTitles]): Main titles on signin page
        subtitle (Union[Unset, SigninCardSubtitles]): Subtitles on signin page
        text_color (Union[Unset, str]):
    """

    btn_color: Union[Unset, str] = UNSET
    btn_text_color: Union[Unset, str] = UNSET
    card_bg_color: Union[Unset, str] = UNSET
    card_border_color: Union[Unset, str] = UNSET
    card_dark_mode: Union[Unset, bool] = False
    card_opacity: Union[Unset, float] = 1.0
    main_title: Union[Unset, "SigninCardMainTitles"] = UNSET
    subtitle: Union[Unset, "SigninCardSubtitles"] = UNSET
    text_color: Union[Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        btn_color = self.btn_color

        btn_text_color = self.btn_text_color

        card_bg_color = self.card_bg_color

        card_border_color = self.card_border_color

        card_dark_mode = self.card_dark_mode

        card_opacity = self.card_opacity

        main_title: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.main_title, Unset):
            main_title = self.main_title.to_dict()

        subtitle: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.subtitle, Unset):
            subtitle = self.subtitle.to_dict()

        text_color = self.text_color

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if btn_color is not UNSET:
            field_dict["btnColor"] = btn_color
        if btn_text_color is not UNSET:
            field_dict["btnTextColor"] = btn_text_color
        if card_bg_color is not UNSET:
            field_dict["cardBgColor"] = card_bg_color
        if card_border_color is not UNSET:
            field_dict["cardBorderColor"] = card_border_color
        if card_dark_mode is not UNSET:
            field_dict["cardDarkMode"] = card_dark_mode
        if card_opacity is not UNSET:
            field_dict["cardOpacity"] = card_opacity
        if main_title is not UNSET:
            field_dict["mainTitle"] = main_title
        if subtitle is not UNSET:
            field_dict["subtitle"] = subtitle
        if text_color is not UNSET:
            field_dict["textColor"] = text_color

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.signin_card_main_titles import SigninCardMainTitles
        from ..models.signin_card_subtitles import SigninCardSubtitles

        d = dict(src_dict)
        btn_color = d.pop("btnColor", UNSET)

        btn_text_color = d.pop("btnTextColor", UNSET)

        card_bg_color = d.pop("cardBgColor", UNSET)

        card_border_color = d.pop("cardBorderColor", UNSET)

        card_dark_mode = d.pop("cardDarkMode", UNSET)

        card_opacity = d.pop("cardOpacity", UNSET)

        _main_title = d.pop("mainTitle", UNSET)
        main_title: Union[Unset, SigninCardMainTitles]
        if isinstance(_main_title, Unset):
            main_title = UNSET
        else:
            main_title = SigninCardMainTitles.from_dict(_main_title)

        _subtitle = d.pop("subtitle", UNSET)
        subtitle: Union[Unset, SigninCardSubtitles]
        if isinstance(_subtitle, Unset):
            subtitle = UNSET
        else:
            subtitle = SigninCardSubtitles.from_dict(_subtitle)

        text_color = d.pop("textColor", UNSET)

        signin_card_form = cls(
            btn_color=btn_color,
            btn_text_color=btn_text_color,
            card_bg_color=card_bg_color,
            card_border_color=card_border_color,
            card_dark_mode=card_dark_mode,
            card_opacity=card_opacity,
            main_title=main_title,
            subtitle=subtitle,
            text_color=text_color,
        )

        return signin_card_form



from http import HTTPStatus
from typing import Any, Optional, Union, cast

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.ack import Ack
from ...models.index_document_indexes_item import IndexDocumentIndexesItem
from ...types import UNSET, Response, Unset


def _get_kwargs(
    project_name: str,
    doc_id: str,
    *,
    indexes: Union[Unset, list[IndexDocumentIndexesItem]] = UNSET,
) -> dict[str, Any]:

    params: dict[str, Any] = {}

    json_indexes: Union[Unset, list[str]] = UNSET
    if not isinstance(indexes, Unset):
        json_indexes = []
        for indexes_item_data in indexes:
            indexes_item = indexes_item_data.value
            json_indexes.append(indexes_item)

    params["indexes"] = json_indexes

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": "/projects/{project_name}/documents/{doc_id}/_index".format(
            project_name=project_name,
            doc_id=doc_id,
        ),
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Ack, Any]]:
    if response.status_code == 200:
        response_200 = Ack.from_dict(response.json())

        return response_200
    if response.status_code == 404:
        response_404 = cast(Any, None)
        return response_404
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Ack, Any]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_name: str,
    doc_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    indexes: Union[Unset, list[IndexDocumentIndexesItem]] = UNSET,
) -> Response[Union[Ack, Any]]:
    """Index a document already in db

    Args:
        project_name (str):
        doc_id (str):
        indexes (Union[Unset, list[IndexDocumentIndexesItem]]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Ack, Any]]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        doc_id=doc_id,
        indexes=indexes,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_name: str,
    doc_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    indexes: Union[Unset, list[IndexDocumentIndexesItem]] = UNSET,
) -> Optional[Union[Ack, Any]]:
    """Index a document already in db

    Args:
        project_name (str):
        doc_id (str):
        indexes (Union[Unset, list[IndexDocumentIndexesItem]]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Ack, Any]
    """

    return sync_detailed(
        project_name=project_name,
        doc_id=doc_id,
        client=client,
        indexes=indexes,
    ).parsed


async def asyncio_detailed(
    project_name: str,
    doc_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    indexes: Union[Unset, list[IndexDocumentIndexesItem]] = UNSET,
) -> Response[Union[Ack, Any]]:
    """Index a document already in db

    Args:
        project_name (str):
        doc_id (str):
        indexes (Union[Unset, list[IndexDocumentIndexesItem]]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Ack, Any]]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        doc_id=doc_id,
        indexes=indexes,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_name: str,
    doc_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    indexes: Union[Unset, list[IndexDocumentIndexesItem]] = UNSET,
) -> Optional[Union[Ack, Any]]:
    """Index a document already in db

    Args:
        project_name (str):
        doc_id (str):
        indexes (Union[Unset, list[IndexDocumentIndexesItem]]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Ack, Any]
    """

    return (
        await asyncio_detailed(
            project_name=project_name,
            doc_id=doc_id,
            client=client,
            indexes=indexes,
        )
    ).parsed



from collections.abc import Mapping
from io import BytesIO
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, File, FileJsonType, Unset

T = TypeVar("T", bound="DeprecatedAnnotateBinaryWithPlanRefBody")


@_attrs_define
class DeprecatedAnnotateBinaryWithPlanRefBody:
    """
    Attributes:
        file (Union[Unset, File]):
    """

    file: Union[Unset, File] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        file: Union[Unset, FileJsonType] = UNSET
        if not isinstance(self.file, Unset):
            file = self.file.to_tuple()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if file is not UNSET:
            field_dict["file"] = file

        return field_dict

    def to_multipart(self) -> dict[str, Any]:
        file: Union[Unset, FileJsonType] = UNSET
        if not isinstance(self.file, Unset):
            file = self.file.to_tuple()

        field_dict: dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = (None, str(prop).encode(), "text/plain")

        field_dict.update({})
        if file is not UNSET:
            field_dict["file"] = file

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        _file = d.pop("file", UNSET)
        file: Union[Unset, File]
        if isinstance(_file, Unset):
            file = UNSET
        else:
            file = File(payload=BytesIO(_file))

        deprecated_annotate_binary_with_plan_ref_body = cls(
            file=file,
        )

        deprecated_annotate_binary_with_plan_ref_body.additional_properties = d
        return deprecated_annotate_binary_with_plan_ref_body

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="LabelSet")


@_attrs_define
class LabelSet:
    """
    Attributes:
        created_at (Union[Unset, str]):
        created_by (Union[Unset, str]):
        exclusive_classes (Union[Unset, bool]):  Default: False.
        guideline (Union[Unset, str]):
        label (Union[Unset, str]):
        modified_at (Union[Unset, str]):
        name (Union[Unset, str]):
        nature (Union[Unset, str]):
        tags (Union[Unset, list[str]]):
    """

    created_at: Union[Unset, str] = UNSET
    created_by: Union[Unset, str] = UNSET
    exclusive_classes: Union[Unset, bool] = False
    guideline: Union[Unset, str] = UNSET
    label: Union[Unset, str] = UNSET
    modified_at: Union[Unset, str] = UNSET
    name: Union[Unset, str] = UNSET
    nature: Union[Unset, str] = UNSET
    tags: Union[Unset, list[str]] = UNSET

    def to_dict(self) -> dict[str, Any]:
        created_at = self.created_at

        created_by = self.created_by

        exclusive_classes = self.exclusive_classes

        guideline = self.guideline

        label = self.label

        modified_at = self.modified_at

        name = self.name

        nature = self.nature

        tags: Union[Unset, list[str]] = UNSET
        if not isinstance(self.tags, Unset):
            tags = self.tags

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if created_by is not UNSET:
            field_dict["createdBy"] = created_by
        if exclusive_classes is not UNSET:
            field_dict["exclusiveClasses"] = exclusive_classes
        if guideline is not UNSET:
            field_dict["guideline"] = guideline
        if label is not UNSET:
            field_dict["label"] = label
        if modified_at is not UNSET:
            field_dict["modifiedAt"] = modified_at
        if name is not UNSET:
            field_dict["name"] = name
        if nature is not UNSET:
            field_dict["nature"] = nature
        if tags is not UNSET:
            field_dict["tags"] = tags

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        created_at = d.pop("createdAt", UNSET)

        created_by = d.pop("createdBy", UNSET)

        exclusive_classes = d.pop("exclusiveClasses", UNSET)

        guideline = d.pop("guideline", UNSET)

        label = d.pop("label", UNSET)

        modified_at = d.pop("modifiedAt", UNSET)

        name = d.pop("name", UNSET)

        nature = d.pop("nature", UNSET)

        tags = cast(list[str], d.pop("tags", UNSET))

        label_set = cls(
            created_at=created_at,
            created_by=created_by,
            exclusive_classes=exclusive_classes,
            guideline=guideline,
            label=label,
            modified_at=modified_at,
            name=name,
            nature=nature,
            tags=tags,
        )

        return label_set



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define

if TYPE_CHECKING:
    from ..models.share_mode import ShareMode


T = TypeVar("T", bound="UserShare")


@_attrs_define
class UserShare:
    """
    Attributes:
        mode (ShareMode):
        username (str):
    """

    mode: "ShareMode"
    username: str

    def to_dict(self) -> dict[str, Any]:
        mode = self.mode.to_dict()

        username = self.username

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "mode": mode,
                "username": username,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.share_mode import ShareMode

        d = dict(src_dict)
        mode = ShareMode.from_dict(d.pop("mode"))

        username = d.pop("username")

        user_share = cls(
            mode=mode,
            username=username,
        )

        return user_share



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define

if TYPE_CHECKING:
    from ..models.batch_migration_operation_users import BatchMigrationOperationUsers
    from ..models.batch_migration_receive import BatchMigrationReceive


T = TypeVar("T", bound="BatchMigrationOperation")


@_attrs_define
class BatchMigrationOperation:
    """
    Attributes:
        receive (BatchMigrationReceive):
        users (BatchMigrationOperationUsers): MongoDB filter matching users
    """

    receive: "BatchMigrationReceive"
    users: "BatchMigrationOperationUsers"

    def to_dict(self) -> dict[str, Any]:
        receive = self.receive.to_dict()

        users = self.users.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "receive": receive,
                "users": users,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.batch_migration_operation_users import (
            BatchMigrationOperationUsers,
        )
        from ..models.batch_migration_receive import BatchMigrationReceive

        d = dict(src_dict)
        receive = BatchMigrationReceive.from_dict(d.pop("receive"))

        users = BatchMigrationOperationUsers.from_dict(d.pop("users"))

        batch_migration_operation = cls(
            receive=receive,
            users=users,
        )

        return batch_migration_operation



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define

T = TypeVar("T", bound="LabelCount")


@_attrs_define
class LabelCount:
    """
    Attributes:
        field_id (str):
        count (int):
    """

    field_id: str
    count: int

    def to_dict(self) -> dict[str, Any]:
        field_id = self.field_id

        count = self.count

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "_id": field_id,
                "count": count,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        field_id = d.pop("_id")

        count = d.pop("count")

        label_count = cls(
            field_id=field_id,
            count=count,
        )

        return label_count



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="QualityFigures")


@_attrs_define
class QualityFigures:
    """
    Attributes:
        support (int):
        ap (Union[Unset, float]):
        f1 (Union[Unset, float]):
        ndcg (Union[Unset, float]):
        precision (Union[Unset, float]):
        recall (Union[Unset, float]):
        roc_auc (Union[Unset, float]):
        rr (Union[Unset, float]):
    """

    support: int
    ap: Union[Unset, float] = UNSET
    f1: Union[Unset, float] = UNSET
    ndcg: Union[Unset, float] = UNSET
    precision: Union[Unset, float] = UNSET
    recall: Union[Unset, float] = UNSET
    roc_auc: Union[Unset, float] = UNSET
    rr: Union[Unset, float] = UNSET

    def to_dict(self) -> dict[str, Any]:
        support = self.support

        ap = self.ap

        f1 = self.f1

        ndcg = self.ndcg

        precision = self.precision

        recall = self.recall

        roc_auc = self.roc_auc

        rr = self.rr

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "support": support,
            }
        )
        if ap is not UNSET:
            field_dict["ap"] = ap
        if f1 is not UNSET:
            field_dict["f1"] = f1
        if ndcg is not UNSET:
            field_dict["ndcg"] = ndcg
        if precision is not UNSET:
            field_dict["precision"] = precision
        if recall is not UNSET:
            field_dict["recall"] = recall
        if roc_auc is not UNSET:
            field_dict["roc_auc"] = roc_auc
        if rr is not UNSET:
            field_dict["rr"] = rr

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        support = d.pop("support")

        ap = d.pop("ap", UNSET)

        f1 = d.pop("f1", UNSET)

        ndcg = d.pop("ndcg", UNSET)

        precision = d.pop("precision", UNSET)

        recall = d.pop("recall", UNSET)

        roc_auc = d.pop("roc_auc", UNSET)

        rr = d.pop("rr", UNSET)

        quality_figures = cls(
            support=support,
            ap=ap,
            f1=f1,
            ndcg=ndcg,
            precision=precision,
            recall=recall,
            roc_auc=roc_auc,
            rr=rr,
        )

        return quality_figures



""" Contains all the data models used in inputs/outputs """

from .ack import Ack
from .aggregation import Aggregation
from .alt_text import AltText
from .annotate_binary_form import AnnotateBinaryForm
from .annotate_binary_with_project_annotator_body import (
    AnnotateBinaryWithProjectAnnotatorBody,
)
from .annotate_binary_with_project_body import AnnotateBinaryWithProjectBody
from .annotate_documents_with_pipeline import AnnotateDocumentsWithPipeline
from .annotate_format_binary_with_project_annotator_body import (
    AnnotateFormatBinaryWithProjectAnnotatorBody,
)
from .annotate_text_with_pipeline import AnnotateTextWithPipeline
from .annotated_doc_alt_text import AnnotatedDocAltText
from .annotated_doc_annotation import AnnotatedDocAnnotation
from .annotated_doc_annotation_creation_mode import AnnotatedDocAnnotationCreationMode
from .annotated_doc_annotation_properties import AnnotatedDocAnnotationProperties
from .annotated_doc_category import AnnotatedDocCategory
from .annotated_doc_category_creation_mode import AnnotatedDocCategoryCreationMode
from .annotated_doc_category_properties import AnnotatedDocCategoryProperties
from .annotated_doc_sentence import AnnotatedDocSentence
from .annotated_doc_sentence_metadata import AnnotatedDocSentenceMetadata
from .annotated_document import AnnotatedDocument
from .annotated_document_metadata import AnnotatedDocumentMetadata
from .annotation import Annotation
from .annotation_creation_mode import AnnotationCreationMode
from .annotation_facets import AnnotationFacets
from .annotation_id import AnnotationId
from .annotation_metrics import AnnotationMetrics
from .annotation_patch import AnnotationPatch
from .annotation_patch_status import AnnotationPatchStatus
from .annotation_plan import AnnotationPlan
from .annotation_status import AnnotationStatus
from .annotation_term import AnnotationTerm
from .annotation_term_properties import AnnotationTermProperties
from .annotator import Annotator
from .annotator_multimap import AnnotatorMultimap
from .app_config import AppConfig
from .apply_to import ApplyTo
from .batch_chown_chmod import BatchChownChmod
from .batch_chown_chmod_migration import BatchChownChmodMigration
from .batch_chown_chmod_result import BatchChownChmodResult
from .batch_chown_chmod_virtual_target_users_item import (
    BatchChownChmodVirtualTargetUsersItem,
)
from .batch_errors import BatchErrors
from .batch_migration_operation import BatchMigrationOperation
from .batch_migration_operation_users import BatchMigrationOperationUsers
from .batch_migration_receive import BatchMigrationReceive
from .bearer_token import BearerToken
from .bucket import Bucket
from .categories_facets import CategoriesFacets
from .category import Category
from .category_action import CategoryAction
from .category_creation_mode import CategoryCreationMode
from .category_id import CategoryId
from .category_metrics import CategoryMetrics
from .category_patch import CategoryPatch
from .category_patch_status import CategoryPatchStatus
from .category_status import CategoryStatus
from .classification_config import ClassificationConfig
from .classification_options import ClassificationOptions
from .config_patch_options import ConfigPatchOptions
from .convert_annotation_plan import ConvertAnnotationPlan
from .convert_format_annotation_plan import ConvertFormatAnnotationPlan
from .converter import Converter
from .converter_parameters import ConverterParameters
from .corpus_metrics import CorpusMetrics
from .create_lexicon_response_200 import CreateLexiconResponse200
from .create_project_from_archive_body import CreateProjectFromArchiveBody
from .create_term_body import CreateTermBody
from .create_term_response_200 import CreateTermResponse200
from .create_theme_form import CreateThemeForm
from .create_theme_from_archive_body import CreateThemeFromArchiveBody
from .created_by_count import CreatedByCount
from .credentials import Credentials
from .default_annotation_plan import DefaultAnnotationPlan
from .default_processor_context import DefaultProcessorContext
from .delete_group_result import DeleteGroupResult
from .delete_many_response import DeleteManyResponse
from .delete_response import DeleteResponse
from .deprecated_annotate_binary_with_plan_ref_body import (
    DeprecatedAnnotateBinaryWithPlanRefBody,
)
from .deprecated_annotate_format_binary_with_plan_ref_body import (
    DeprecatedAnnotateFormatBinaryWithPlanRefBody,
)
from .doc_alt_text import DocAltText
from .doc_annotation import DocAnnotation
from .doc_annotation_creation_mode import DocAnnotationCreationMode
from .doc_annotation_properties import DocAnnotationProperties
from .doc_annotation_status import DocAnnotationStatus
from .doc_category import DocCategory
from .doc_category_creation_mode import DocCategoryCreationMode
from .doc_category_properties import DocCategoryProperties
from .doc_category_status import DocCategoryStatus
from .doc_sentence import DocSentence
from .doc_sentence_metadata import DocSentenceMetadata
from .document import Document
from .document_facets import DocumentFacets
from .document_hit import DocumentHit
from .document_hits import DocumentHits
from .document_metadata import DocumentMetadata
from .engine_config import EngineConfig
from .engine_config_import_summary import EngineConfigImportSummary
from .engine_name import EngineName
from .error import Error
from .experiment import Experiment
from .experiment_parameters import ExperimentParameters
from .experiment_patch import ExperimentPatch
from .experiment_patch_parameters import ExperimentPatchParameters
from .export_terms_response_200_item import ExportTermsResponse200Item
from .external_databases import ExternalDatabases
from .external_resources import ExternalResources
from .filtering_params import FilteringParams
from .find_similar_segments_search_type import FindSimilarSegmentsSearchType
from .format_binary_form import FormatBinaryForm
from .format_documents_with_many import FormatDocumentsWithMany
from .format_text_with_many import FormatTextWithMany
from .formatter import Formatter
from .formatter_parameters import FormatterParameters
from .gazetteer import Gazetteer
from .gazetteer_parameters import GazetteerParameters
from .gazetteer_patch import GazetteerPatch
from .gazetteer_patch_parameters import GazetteerPatchParameters
from .general_app_bar import GeneralAppBar
from .general_config import GeneralConfig
from .general_footer import GeneralFooter
from .general_toolbar import GeneralToolbar
from .get_base_theme_config_response_200 import GetBaseThemeConfigResponse200
from .get_favorite_theme_scope import GetFavoriteThemeScope
from .get_global_messages_output_format import GetGlobalMessagesOutputFormat
from .get_global_messages_scopes_item import GetGlobalMessagesScopesItem
from .get_term_response_200 import GetTermResponse200
from .get_theme_config_schema_response_200 import GetThemeConfigSchemaResponse200
from .get_themes_scope import GetThemesScope
from .global_message import GlobalMessage
from .global_message_localized import GlobalMessageLocalized
from .global_message_patch import GlobalMessagePatch
from .global_message_patch_localized import GlobalMessagePatchLocalized
from .global_message_patch_scope import GlobalMessagePatchScope
from .global_message_scope import GlobalMessageScope
from .group_desc import GroupDesc
from .group_desc_mapping_discriminator import GroupDescMappingDiscriminator
from .group_name import GroupName
from .group_patch import GroupPatch
from .group_patch_mapping_discriminator import GroupPatchMappingDiscriminator
from .group_share import GroupShare
from .http_service_metadata import HttpServiceMetadata
from .http_service_metadata_operations import HttpServiceMetadataOperations
from .http_service_metadata_service import HttpServiceMetadataService
from .http_service_record import HttpServiceRecord
from .import_archive_body import ImportArchiveBody
from .import_models_body import ImportModelsBody
from .imported_doc_annotation import ImportedDocAnnotation
from .imported_doc_annotation_creation_mode import ImportedDocAnnotationCreationMode
from .imported_doc_annotation_properties import ImportedDocAnnotationProperties
from .imported_doc_category import ImportedDocCategory
from .imported_doc_category_creation_mode import ImportedDocCategoryCreationMode
from .imported_doc_category_properties import ImportedDocCategoryProperties
from .imported_document import ImportedDocument
from .imported_document_metadata import ImportedDocumentMetadata
from .index_document_indexes_item import IndexDocumentIndexesItem
from .input_document import InputDocument
from .input_document_metadata import InputDocumentMetadata
from .item_count import ItemCount
from .item_ref import ItemRef
from .label import Label
from .label_count import LabelCount
from .label_names import LabelNames
from .label_set import LabelSet
from .label_set_update import LabelSetUpdate
from .label_update import LabelUpdate
from .launch_document_import_body import LaunchDocumentImportBody
from .launch_document_import_clean_text import LaunchDocumentImportCleanText
from .launch_document_import_segmentation_policy import (
    LaunchDocumentImportSegmentationPolicy,
)
from .launch_json_documents_import_clean_text import LaunchJsonDocumentsImportCleanText
from .launch_json_documents_import_segmentation_policy import (
    LaunchJsonDocumentsImportSegmentationPolicy,
)
from .launch_project_restoration_from_backup_body import (
    LaunchProjectRestorationFromBackupBody,
)
from .launch_uploaded_document_import_clean_text import (
    LaunchUploadedDocumentImportCleanText,
)
from .launch_uploaded_document_import_segmentation_policy import (
    LaunchUploadedDocumentImportSegmentationPolicy,
)
from .lexicon import Lexicon
from .lexicon_update import LexiconUpdate
from .localized_message import LocalizedMessage
from .localized_message_format import LocalizedMessageFormat
from .localized_message_templating import LocalizedMessageTemplating
from .maybe_create_projects_and_import_models_from_archive_body import (
    MaybeCreateProjectsAndImportModelsFromArchiveBody,
)
from .message_audience import MessageAudience
from .message_id import MessageId
from .message_mark import MessageMark
from .metadata_count import MetadataCount
from .model_metrics import ModelMetrics
from .model_metrics_options import ModelMetricsOptions
from .models_metrics import ModelsMetrics
from .named_annotation_plan import NamedAnnotationPlan
from .named_vector import NamedVector
from .named_vector_creation_mode import NamedVectorCreationMode
from .named_vector_properties import NamedVectorProperties
from .new_experiment import NewExperiment
from .new_experiment_parameters import NewExperimentParameters
from .new_gazetteer import NewGazetteer
from .new_gazetteer_parameters import NewGazetteerParameters
from .new_global_message import NewGlobalMessage
from .new_global_message_localized import NewGlobalMessageLocalized
from .new_global_message_scope import NewGlobalMessageScope
from .new_group_desc import NewGroupDesc
from .new_group_desc_mapping_discriminator import NewGroupDescMappingDiscriminator
from .new_named_annotation_plan import NewNamedAnnotationPlan
from .new_role import NewRole
from .new_suggester import NewSuggester
from .new_suggester_parameters import NewSuggesterParameters
from .new_theme import NewTheme
from .new_user import NewUser
from .operation_count import OperationCount
from .output_params import OutputParams
from .ownership_change import OwnershipChange
from .partial_label import PartialLabel
from .partial_lexicon import PartialLexicon
from .plan_operation_response import PlanOperationResponse
from .plan_patch import PlanPatch
from .platform_share import PlatformShare
from .project_annotators import ProjectAnnotators
from .project_bean import ProjectBean
from .project_config_creation import ProjectConfigCreation
from .project_config_creation_properties import ProjectConfigCreationProperties
from .project_open_session import ProjectOpenSession
from .project_open_session_state import ProjectOpenSessionState
from .project_property import ProjectProperty
from .project_status import ProjectStatus
from .project_user_share import ProjectUserShare
from .projects_annotators import ProjectsAnnotators
from .quality_figures import QualityFigures
from .question_answering_params import QuestionAnsweringParams
from .question_answering_params_language_detection import (
    QuestionAnsweringParamsLanguageDetection,
)
from .report import Report
from .report_classes import ReportClasses
from .request_jwt_token_project_access_mode import RequestJwtTokenProjectAccessMode
from .role_desc import RoleDesc
from .role_update import RoleUpdate
from .search_documents_search_type import SearchDocumentsSearchType
from .search_filter import SearchFilter
from .search_filter_filter_selector import SearchFilterFilterSelector
from .search_filter_filter_type import SearchFilterFilterType
from .search_params import SearchParams
from .search_params_type import SearchParamsType
from .search_request import SearchRequest
from .search_segments_search_type import SearchSegmentsSearchType
from .search_terms_search_type import SearchTermsSearchType
from .search_total import SearchTotal
from .search_total_relation import SearchTotalRelation
from .segment import Segment
from .segment_hit import SegmentHit
from .segment_hits import SegmentHits
from .segment_metadata import SegmentMetadata
from .segmenter import Segmenter
from .segmenter_parameters import SegmenterParameters
from .set_theme_as_favorite_scope import SetThemeAsFavoriteScope
from .share_mode import ShareMode
from .sherpa_job_bean import SherpaJobBean
from .sherpa_job_bean_status import SherpaJobBeanStatus
from .sherpa_job_bean_type import SherpaJobBeanType
from .signin_app_bar import SigninAppBar
from .signin_card_form import SigninCardForm
from .signin_card_main_titles import SigninCardMainTitles
from .signin_card_subtitles import SigninCardSubtitles
from .signin_config import SigninConfig
from .signin_footer import SigninFooter
from .simple_group import SimpleGroup
from .simple_group_desc import SimpleGroupDesc
from .simple_group_desc_mapping_discriminator import SimpleGroupDescMappingDiscriminator
from .simple_group_membership_desc import SimpleGroupMembershipDesc
from .simple_metadata import SimpleMetadata
from .simple_user import SimpleUser
from .suggester import Suggester
from .suggester_parameters import SuggesterParameters
from .suggester_patch import SuggesterPatch
from .suggester_patch_parameters import SuggesterPatchParameters
from .suggestion_facets import SuggestionFacets
from .term_hit import TermHit
from .term_hit_term import TermHitTerm
from .term_hits import TermHits
from .term_identifier import TermIdentifier
from .term_import import TermImport
from .term_importer_spec import TermImporterSpec
from .term_importer_spec_parameters import TermImporterSpecParameters
from .text_count import TextCount
from .theme import Theme
from .theme_config import ThemeConfig
from .theme_id import ThemeId
from .theme_media import ThemeMedia
from .theme_update import ThemeUpdate
from .update_theme_form import UpdateThemeForm
from .upload_files_body import UploadFilesBody
from .uploaded_file import UploadedFile
from .uploaded_file_info import UploadedFileInfo
from .user_group_ref import UserGroupRef
from .user_permissions_update import UserPermissionsUpdate
from .user_profile import UserProfile
from .user_profile_update import UserProfileUpdate
from .user_response import UserResponse
from .user_share import UserShare
from .users_response import UsersResponse
from .vector_params import VectorParams
from .vector_params_native_rrf import VectorParamsNativeRRF
from .vuetify_config import VuetifyConfig
from .vuetify_dark_theme import VuetifyDarkTheme
from .vuetify_light_theme import VuetifyLightTheme
from .vuetify_themes import VuetifyThemes
from .with_annotator import WithAnnotator
from .with_annotator_condition import WithAnnotatorCondition
from .with_annotator_parameters import WithAnnotatorParameters
from .with_converter import WithConverter
from .with_converter_condition import WithConverterCondition
from .with_converter_parameters import WithConverterParameters
from .with_language_guesser import WithLanguageGuesser
from .with_language_guesser_condition import WithLanguageGuesserCondition
from .with_language_guesser_parameters import WithLanguageGuesserParameters
from .with_processor import WithProcessor
from .with_processor_condition import WithProcessorCondition
from .with_processor_parameters import WithProcessorParameters
from .with_segmenter import WithSegmenter
from .with_segmenter_condition import WithSegmenterCondition
from .with_segmenter_parameters import WithSegmenterParameters
from .with_vectorizer import WithVectorizer
from .with_vectorizer_condition import WithVectorizerCondition
from .with_vectorizer_parameters import WithVectorizerParameters

__all__ = (
    "Ack",
    "Aggregation",
    "AltText",
    "AnnotateBinaryForm",
    "AnnotateBinaryWithProjectAnnotatorBody",
    "AnnotateBinaryWithProjectBody",
    "AnnotatedDocAltText",
    "AnnotatedDocAnnotation",
    "AnnotatedDocAnnotationCreationMode",
    "AnnotatedDocAnnotationProperties",
    "AnnotatedDocCategory",
    "AnnotatedDocCategoryCreationMode",
    "AnnotatedDocCategoryProperties",
    "AnnotatedDocSentence",
    "AnnotatedDocSentenceMetadata",
    "AnnotatedDocument",
    "AnnotatedDocumentMetadata",
    "AnnotateDocumentsWithPipeline",
    "AnnotateFormatBinaryWithProjectAnnotatorBody",
    "AnnotateTextWithPipeline",
    "Annotation",
    "AnnotationCreationMode",
    "AnnotationFacets",
    "AnnotationId",
    "AnnotationMetrics",
    "AnnotationPatch",
    "AnnotationPatchStatus",
    "AnnotationPlan",
    "AnnotationStatus",
    "AnnotationTerm",
    "AnnotationTermProperties",
    "Annotator",
    "AnnotatorMultimap",
    "AppConfig",
    "ApplyTo",
    "BatchChownChmod",
    "BatchChownChmodMigration",
    "BatchChownChmodResult",
    "BatchChownChmodVirtualTargetUsersItem",
    "BatchErrors",
    "BatchMigrationOperation",
    "BatchMigrationOperationUsers",
    "BatchMigrationReceive",
    "BearerToken",
    "Bucket",
    "CategoriesFacets",
    "Category",
    "CategoryAction",
    "CategoryCreationMode",
    "CategoryId",
    "CategoryMetrics",
    "CategoryPatch",
    "CategoryPatchStatus",
    "CategoryStatus",
    "ClassificationConfig",
    "ClassificationOptions",
    "ConfigPatchOptions",
    "ConvertAnnotationPlan",
    "Converter",
    "ConverterParameters",
    "ConvertFormatAnnotationPlan",
    "CorpusMetrics",
    "CreatedByCount",
    "CreateLexiconResponse200",
    "CreateProjectFromArchiveBody",
    "CreateTermBody",
    "CreateTermResponse200",
    "CreateThemeForm",
    "CreateThemeFromArchiveBody",
    "Credentials",
    "DefaultAnnotationPlan",
    "DefaultProcessorContext",
    "DeleteGroupResult",
    "DeleteManyResponse",
    "DeleteResponse",
    "DeprecatedAnnotateBinaryWithPlanRefBody",
    "DeprecatedAnnotateFormatBinaryWithPlanRefBody",
    "DocAltText",
    "DocAnnotation",
    "DocAnnotationCreationMode",
    "DocAnnotationProperties",
    "DocAnnotationStatus",
    "DocCategory",
    "DocCategoryCreationMode",
    "DocCategoryProperties",
    "DocCategoryStatus",
    "DocSentence",
    "DocSentenceMetadata",
    "Document",
    "DocumentFacets",
    "DocumentHit",
    "DocumentHits",
    "DocumentMetadata",
    "EngineConfig",
    "EngineConfigImportSummary",
    "EngineName",
    "Error",
    "Experiment",
    "ExperimentParameters",
    "ExperimentPatch",
    "ExperimentPatchParameters",
    "ExportTermsResponse200Item",
    "ExternalDatabases",
    "ExternalResources",
    "FilteringParams",
    "FindSimilarSegmentsSearchType",
    "FormatBinaryForm",
    "FormatDocumentsWithMany",
    "Formatter",
    "FormatterParameters",
    "FormatTextWithMany",
    "Gazetteer",
    "GazetteerParameters",
    "GazetteerPatch",
    "GazetteerPatchParameters",
    "GeneralAppBar",
    "GeneralConfig",
    "GeneralFooter",
    "GeneralToolbar",
    "GetBaseThemeConfigResponse200",
    "GetFavoriteThemeScope",
    "GetGlobalMessagesOutputFormat",
    "GetGlobalMessagesScopesItem",
    "GetTermResponse200",
    "GetThemeConfigSchemaResponse200",
    "GetThemesScope",
    "GlobalMessage",
    "GlobalMessageLocalized",
    "GlobalMessagePatch",
    "GlobalMessagePatchLocalized",
    "GlobalMessagePatchScope",
    "GlobalMessageScope",
    "GroupDesc",
    "GroupDescMappingDiscriminator",
    "GroupName",
    "GroupPatch",
    "GroupPatchMappingDiscriminator",
    "GroupShare",
    "HttpServiceMetadata",
    "HttpServiceMetadataOperations",
    "HttpServiceMetadataService",
    "HttpServiceRecord",
    "ImportArchiveBody",
    "ImportedDocAnnotation",
    "ImportedDocAnnotationCreationMode",
    "ImportedDocAnnotationProperties",
    "ImportedDocCategory",
    "ImportedDocCategoryCreationMode",
    "ImportedDocCategoryProperties",
    "ImportedDocument",
    "ImportedDocumentMetadata",
    "ImportModelsBody",
    "IndexDocumentIndexesItem",
    "InputDocument",
    "InputDocumentMetadata",
    "ItemCount",
    "ItemRef",
    "Label",
    "LabelCount",
    "LabelNames",
    "LabelSet",
    "LabelSetUpdate",
    "LabelUpdate",
    "LaunchDocumentImportBody",
    "LaunchDocumentImportCleanText",
    "LaunchDocumentImportSegmentationPolicy",
    "LaunchJsonDocumentsImportCleanText",
    "LaunchJsonDocumentsImportSegmentationPolicy",
    "LaunchProjectRestorationFromBackupBody",
    "LaunchUploadedDocumentImportCleanText",
    "LaunchUploadedDocumentImportSegmentationPolicy",
    "Lexicon",
    "LexiconUpdate",
    "LocalizedMessage",
    "LocalizedMessageFormat",
    "LocalizedMessageTemplating",
    "MaybeCreateProjectsAndImportModelsFromArchiveBody",
    "MessageAudience",
    "MessageId",
    "MessageMark",
    "MetadataCount",
    "ModelMetrics",
    "ModelMetricsOptions",
    "ModelsMetrics",
    "NamedAnnotationPlan",
    "NamedVector",
    "NamedVectorCreationMode",
    "NamedVectorProperties",
    "NewExperiment",
    "NewExperimentParameters",
    "NewGazetteer",
    "NewGazetteerParameters",
    "NewGlobalMessage",
    "NewGlobalMessageLocalized",
    "NewGlobalMessageScope",
    "NewGroupDesc",
    "NewGroupDescMappingDiscriminator",
    "NewNamedAnnotationPlan",
    "NewRole",
    "NewSuggester",
    "NewSuggesterParameters",
    "NewTheme",
    "NewUser",
    "OperationCount",
    "OutputParams",
    "OwnershipChange",
    "PartialLabel",
    "PartialLexicon",
    "PlanOperationResponse",
    "PlanPatch",
    "PlatformShare",
    "ProjectAnnotators",
    "ProjectBean",
    "ProjectConfigCreation",
    "ProjectConfigCreationProperties",
    "ProjectOpenSession",
    "ProjectOpenSessionState",
    "ProjectProperty",
    "ProjectsAnnotators",
    "ProjectStatus",
    "ProjectUserShare",
    "QualityFigures",
    "QuestionAnsweringParams",
    "QuestionAnsweringParamsLanguageDetection",
    "Report",
    "ReportClasses",
    "RequestJwtTokenProjectAccessMode",
    "RoleDesc",
    "RoleUpdate",
    "SearchDocumentsSearchType",
    "SearchFilter",
    "SearchFilterFilterSelector",
    "SearchFilterFilterType",
    "SearchParams",
    "SearchParamsType",
    "SearchRequest",
    "SearchSegmentsSearchType",
    "SearchTermsSearchType",
    "SearchTotal",
    "SearchTotalRelation",
    "Segment",
    "Segmenter",
    "SegmenterParameters",
    "SegmentHit",
    "SegmentHits",
    "SegmentMetadata",
    "SetThemeAsFavoriteScope",
    "ShareMode",
    "SherpaJobBean",
    "SherpaJobBeanStatus",
    "SherpaJobBeanType",
    "SigninAppBar",
    "SigninCardForm",
    "SigninCardMainTitles",
    "SigninCardSubtitles",
    "SigninConfig",
    "SigninFooter",
    "SimpleGroup",
    "SimpleGroupDesc",
    "SimpleGroupDescMappingDiscriminator",
    "SimpleGroupMembershipDesc",
    "SimpleMetadata",
    "SimpleUser",
    "Suggester",
    "SuggesterParameters",
    "SuggesterPatch",
    "SuggesterPatchParameters",
    "SuggestionFacets",
    "TermHit",
    "TermHits",
    "TermHitTerm",
    "TermIdentifier",
    "TermImport",
    "TermImporterSpec",
    "TermImporterSpecParameters",
    "TextCount",
    "Theme",
    "ThemeConfig",
    "ThemeId",
    "ThemeMedia",
    "ThemeUpdate",
    "UpdateThemeForm",
    "UploadedFile",
    "UploadedFileInfo",
    "UploadFilesBody",
    "UserGroupRef",
    "UserPermissionsUpdate",
    "UserProfile",
    "UserProfileUpdate",
    "UserResponse",
    "UserShare",
    "UsersResponse",
    "VectorParams",
    "VectorParamsNativeRRF",
    "VuetifyConfig",
    "VuetifyDarkTheme",
    "VuetifyLightTheme",
    "VuetifyThemes",
    "WithAnnotator",
    "WithAnnotatorCondition",
    "WithAnnotatorParameters",
    "WithConverter",
    "WithConverterCondition",
    "WithConverterParameters",
    "WithLanguageGuesser",
    "WithLanguageGuesserCondition",
    "WithLanguageGuesserParameters",
    "WithProcessor",
    "WithProcessorCondition",
    "WithProcessorParameters",
    "WithSegmenter",
    "WithSegmenterCondition",
    "WithSegmenterParameters",
    "WithVectorizer",
    "WithVectorizerCondition",
    "WithVectorizerParameters",
)



from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.bearer_token import BearerToken
from ...models.credentials import Credentials
from ...models.request_jwt_token_project_access_mode import (
    RequestJwtTokenProjectAccessMode,
)
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    body: Credentials,
    project_filter: Union[Unset, str] = UNSET,
    project_access_mode: Union[Unset, RequestJwtTokenProjectAccessMode] = UNSET,
    annotate_only: Union[Unset, bool] = False,
    login_only: Union[Unset, bool] = False,
    no_permissions: Union[Unset, bool] = False,
    duration: Union[Unset, str] = UNSET,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    params: dict[str, Any] = {}

    params["projectFilter"] = project_filter

    json_project_access_mode: Union[Unset, str] = UNSET
    if not isinstance(project_access_mode, Unset):
        json_project_access_mode = project_access_mode.value

    params["projectAccessMode"] = json_project_access_mode

    params["annotateOnly"] = annotate_only

    params["loginOnly"] = login_only

    params["noPermissions"] = no_permissions

    params["duration"] = duration

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": "/auth/login",
        "params": params,
    }

    _body = body.to_dict()

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[BearerToken]:
    if response.status_code == 200:
        response_200 = BearerToken.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[BearerToken]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: Credentials,
    project_filter: Union[Unset, str] = UNSET,
    project_access_mode: Union[Unset, RequestJwtTokenProjectAccessMode] = UNSET,
    annotate_only: Union[Unset, bool] = False,
    login_only: Union[Unset, bool] = False,
    no_permissions: Union[Unset, bool] = False,
    duration: Union[Unset, str] = UNSET,
) -> Response[BearerToken]:
    """Request a bearer token

    Args:
        project_filter (Union[Unset, str]):
        project_access_mode (Union[Unset, RequestJwtTokenProjectAccessMode]):
        annotate_only (Union[Unset, bool]):  Default: False.
        login_only (Union[Unset, bool]):  Default: False.
        no_permissions (Union[Unset, bool]):  Default: False.
        duration (Union[Unset, str]):
        body (Credentials):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[BearerToken]
    """

    kwargs = _get_kwargs(
        body=body,
        project_filter=project_filter,
        project_access_mode=project_access_mode,
        annotate_only=annotate_only,
        login_only=login_only,
        no_permissions=no_permissions,
        duration=duration,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    body: Credentials,
    project_filter: Union[Unset, str] = UNSET,
    project_access_mode: Union[Unset, RequestJwtTokenProjectAccessMode] = UNSET,
    annotate_only: Union[Unset, bool] = False,
    login_only: Union[Unset, bool] = False,
    no_permissions: Union[Unset, bool] = False,
    duration: Union[Unset, str] = UNSET,
) -> Optional[BearerToken]:
    """Request a bearer token

    Args:
        project_filter (Union[Unset, str]):
        project_access_mode (Union[Unset, RequestJwtTokenProjectAccessMode]):
        annotate_only (Union[Unset, bool]):  Default: False.
        login_only (Union[Unset, bool]):  Default: False.
        no_permissions (Union[Unset, bool]):  Default: False.
        duration (Union[Unset, str]):
        body (Credentials):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        BearerToken
    """

    return sync_detailed(
        client=client,
        body=body,
        project_filter=project_filter,
        project_access_mode=project_access_mode,
        annotate_only=annotate_only,
        login_only=login_only,
        no_permissions=no_permissions,
        duration=duration,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: Credentials,
    project_filter: Union[Unset, str] = UNSET,
    project_access_mode: Union[Unset, RequestJwtTokenProjectAccessMode] = UNSET,
    annotate_only: Union[Unset, bool] = False,
    login_only: Union[Unset, bool] = False,
    no_permissions: Union[Unset, bool] = False,
    duration: Union[Unset, str] = UNSET,
) -> Response[BearerToken]:
    """Request a bearer token

    Args:
        project_filter (Union[Unset, str]):
        project_access_mode (Union[Unset, RequestJwtTokenProjectAccessMode]):
        annotate_only (Union[Unset, bool]):  Default: False.
        login_only (Union[Unset, bool]):  Default: False.
        no_permissions (Union[Unset, bool]):  Default: False.
        duration (Union[Unset, str]):
        body (Credentials):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[BearerToken]
    """

    kwargs = _get_kwargs(
        body=body,
        project_filter=project_filter,
        project_access_mode=project_access_mode,
        annotate_only=annotate_only,
        login_only=login_only,
        no_permissions=no_permissions,
        duration=duration,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    body: Credentials,
    project_filter: Union[Unset, str] = UNSET,
    project_access_mode: Union[Unset, RequestJwtTokenProjectAccessMode] = UNSET,
    annotate_only: Union[Unset, bool] = False,
    login_only: Union[Unset, bool] = False,
    no_permissions: Union[Unset, bool] = False,
    duration: Union[Unset, str] = UNSET,
) -> Optional[BearerToken]:
    """Request a bearer token

    Args:
        project_filter (Union[Unset, str]):
        project_access_mode (Union[Unset, RequestJwtTokenProjectAccessMode]):
        annotate_only (Union[Unset, bool]):  Default: False.
        login_only (Union[Unset, bool]):  Default: False.
        no_permissions (Union[Unset, bool]):  Default: False.
        duration (Union[Unset, str]):
        body (Credentials):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        BearerToken
    """

    return (
        await asyncio_detailed(
            client=client,
            body=body,
            project_filter=project_filter,
            project_access_mode=project_access_mode,
            annotate_only=annotate_only,
            login_only=login_only,
            no_permissions=no_permissions,
            duration=duration,
        )
    ).parsed



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="ThemeMedia")


@_attrs_define
class ThemeMedia:
    """Images and videos on signin page

    Attributes:
        app_bar_image (Union[Unset, str]):
        bg_image (Union[Unset, str]):
        bg_video (Union[Unset, str]):
    """

    app_bar_image: Union[Unset, str] = UNSET
    bg_image: Union[Unset, str] = UNSET
    bg_video: Union[Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        app_bar_image = self.app_bar_image

        bg_image = self.bg_image

        bg_video = self.bg_video

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if app_bar_image is not UNSET:
            field_dict["appBarImage"] = app_bar_image
        if bg_image is not UNSET:
            field_dict["bgImage"] = bg_image
        if bg_video is not UNSET:
            field_dict["bgVideo"] = bg_video

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        app_bar_image = d.pop("appBarImage", UNSET)

        bg_image = d.pop("bgImage", UNSET)

        bg_video = d.pop("bgVideo", UNSET)

        theme_media = cls(
            app_bar_image=app_bar_image,
            bg_image=bg_image,
            bg_video=bg_video,
        )

        return theme_media



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define

if TYPE_CHECKING:
    from ..models.label_count import LabelCount


T = TypeVar("T", bound="CategoriesFacets")


@_attrs_define
class CategoriesFacets:
    """
    Attributes:
        labels (list['LabelCount']):
    """

    labels: list["LabelCount"]

    def to_dict(self) -> dict[str, Any]:
        labels = []
        for labels_item_data in self.labels:
            labels_item = labels_item_data.to_dict()
            labels.append(labels_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "labels": labels,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.label_count import LabelCount

        d = dict(src_dict)
        labels = []
        _labels = d.pop("labels")
        for labels_item_data in _labels:
            labels_item = LabelCount.from_dict(labels_item_data)

            labels.append(labels_item)

        categories_facets = cls(
            labels=labels,
        )

        return categories_facets



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define

T = TypeVar("T", bound="ApplyTo")


@_attrs_define
class ApplyTo:
    """
    Attributes:
        path (str):
    """

    path: str

    def to_dict(self) -> dict[str, Any]:
        path = self.path

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "path": path,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        path = d.pop("path")

        apply_to = cls(
            path=path,
        )

        return apply_to



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="VuetifyDarkTheme")


@_attrs_define
class VuetifyDarkTheme:
    """Standard dark colors

    Attributes:
        primary (Union[Unset, str]):  Default: '#1976D2'.
        secondary (Union[Unset, str]):  Default: '#EEEEEE'.
    """

    primary: Union[Unset, str] = "#1976D2"
    secondary: Union[Unset, str] = "#EEEEEE"

    def to_dict(self) -> dict[str, Any]:
        primary = self.primary

        secondary = self.secondary

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if primary is not UNSET:
            field_dict["primary"] = primary
        if secondary is not UNSET:
            field_dict["secondary"] = secondary

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        primary = d.pop("primary", UNSET)

        secondary = d.pop("secondary", UNSET)

        vuetify_dark_theme = cls(
            primary=primary,
            secondary=secondary,
        )

        return vuetify_dark_theme



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.batch_migration_operation import BatchMigrationOperation


T = TypeVar("T", bound="BatchChownChmodMigration")


@_attrs_define
class BatchChownChmodMigration:
    """
    Attributes:
        operations (list['BatchMigrationOperation']):
        share_project_with_previous_owner (Union[Unset, bool]):  Default: True.
    """

    operations: list["BatchMigrationOperation"]
    share_project_with_previous_owner: Union[Unset, bool] = True

    def to_dict(self) -> dict[str, Any]:
        operations = []
        for operations_item_data in self.operations:
            operations_item = operations_item_data.to_dict()
            operations.append(operations_item)

        share_project_with_previous_owner = self.share_project_with_previous_owner

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "operations": operations,
            }
        )
        if share_project_with_previous_owner is not UNSET:
            field_dict[
                "shareProjectWithPreviousOwner"
            ] = share_project_with_previous_owner

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.batch_migration_operation import BatchMigrationOperation

        d = dict(src_dict)
        operations = []
        _operations = d.pop("operations")
        for operations_item_data in _operations:
            operations_item = BatchMigrationOperation.from_dict(operations_item_data)

            operations.append(operations_item)

        share_project_with_previous_owner = d.pop(
            "shareProjectWithPreviousOwner", UNSET
        )

        batch_chown_chmod_migration = cls(
            operations=operations,
            share_project_with_previous_owner=share_project_with_previous_owner,
        )

        return batch_chown_chmod_migration



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="NewUser")


@_attrs_define
class NewUser:
    """
    Attributes:
        password (str):
        username (str):
        email (Union[Unset, str]):
        permissions (Union[Unset, list[str]]):
        roles (Union[Unset, list[str]]):
    """

    password: str
    username: str
    email: Union[Unset, str] = UNSET
    permissions: Union[Unset, list[str]] = UNSET
    roles: Union[Unset, list[str]] = UNSET

    def to_dict(self) -> dict[str, Any]:
        password = self.password

        username = self.username

        email = self.email

        permissions: Union[Unset, list[str]] = UNSET
        if not isinstance(self.permissions, Unset):
            permissions = self.permissions

        roles: Union[Unset, list[str]] = UNSET
        if not isinstance(self.roles, Unset):
            roles = self.roles

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "password": password,
                "username": username,
            }
        )
        if email is not UNSET:
            field_dict["email"] = email
        if permissions is not UNSET:
            field_dict["permissions"] = permissions
        if roles is not UNSET:
            field_dict["roles"] = roles

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        password = d.pop("password")

        username = d.pop("username")

        email = d.pop("email", UNSET)

        permissions = cast(list[str], d.pop("permissions", UNSET))

        roles = cast(list[str], d.pop("roles", UNSET))

        new_user = cls(
            password=password,
            username=username,
            email=email,
            permissions=permissions,
            roles=roles,
        )

        return new_user



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="OutputParams")


@_attrs_define
class OutputParams:
    """Search output parameters

    Attributes:
        facets (Union[Unset, bool]): Activate faceted search results Default: False.
        fields (Union[Unset, str]): Hit fields to be returned (e.g. 'annotations,categories' or '!text,!metadata')
        highlight (Union[Unset, bool]): Highlight query terms Default: False.
        return_hits (Union[Unset, bool]): Return hits in addition to answering the question Default: True.
    """

    facets: Union[Unset, bool] = False
    fields: Union[Unset, str] = UNSET
    highlight: Union[Unset, bool] = False
    return_hits: Union[Unset, bool] = True

    def to_dict(self) -> dict[str, Any]:
        facets = self.facets

        fields = self.fields

        highlight = self.highlight

        return_hits = self.return_hits

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if facets is not UNSET:
            field_dict["facets"] = facets
        if fields is not UNSET:
            field_dict["fields"] = fields
        if highlight is not UNSET:
            field_dict["highlight"] = highlight
        if return_hits is not UNSET:
            field_dict["returnHits"] = return_hits

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        facets = d.pop("facets", UNSET)

        fields = d.pop("fields", UNSET)

        highlight = d.pop("highlight", UNSET)

        return_hits = d.pop("returnHits", UNSET)

        output_params = cls(
            facets=facets,
            fields=fields,
            highlight=highlight,
            return_hits=return_hits,
        )

        return output_params



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define

if TYPE_CHECKING:
    from ..models.share_mode import ShareMode


T = TypeVar("T", bound="PlatformShare")


@_attrs_define
class PlatformShare:
    """
    Attributes:
        can_revoke (bool):
        mode (ShareMode):
    """

    can_revoke: bool
    mode: "ShareMode"

    def to_dict(self) -> dict[str, Any]:
        can_revoke = self.can_revoke

        mode = self.mode.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "canRevoke": can_revoke,
                "mode": mode,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.share_mode import ShareMode

        d = dict(src_dict)
        can_revoke = d.pop("canRevoke")

        mode = ShareMode.from_dict(d.pop("mode"))

        platform_share = cls(
            can_revoke=can_revoke,
            mode=mode,
        )

        return platform_share



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..models.group_desc_mapping_discriminator import GroupDescMappingDiscriminator
from ..types import UNSET, Unset

T = TypeVar("T", bound="GroupDesc")


@_attrs_define
class GroupDesc:
    """
    Attributes:
        label (str):
        login_allowed (bool):
        max_users (int):
        name (str):
        attached_roles (Union[Unset, list[str]]):
        created_at (Union[Unset, str]):
        created_by (Union[Unset, str]):
        identifier (Union[Unset, str]):
        mapping_discriminator (Union[Unset, GroupDescMappingDiscriminator]):
        max_docs_per_project (Union[Unset, int]):
        max_projects (Union[Unset, int]):
        max_projects_per_user (Union[Unset, int]):
        modified_at (Union[Unset, str]):
        modified_by (Union[Unset, str]):
        system_attached_roles (Union[Unset, list[str]]):
    """

    label: str
    login_allowed: bool
    max_users: int
    name: str
    attached_roles: Union[Unset, list[str]] = UNSET
    created_at: Union[Unset, str] = UNSET
    created_by: Union[Unset, str] = UNSET
    identifier: Union[Unset, str] = UNSET
    mapping_discriminator: Union[Unset, GroupDescMappingDiscriminator] = UNSET
    max_docs_per_project: Union[Unset, int] = UNSET
    max_projects: Union[Unset, int] = UNSET
    max_projects_per_user: Union[Unset, int] = UNSET
    modified_at: Union[Unset, str] = UNSET
    modified_by: Union[Unset, str] = UNSET
    system_attached_roles: Union[Unset, list[str]] = UNSET

    def to_dict(self) -> dict[str, Any]:
        label = self.label

        login_allowed = self.login_allowed

        max_users = self.max_users

        name = self.name

        attached_roles: Union[Unset, list[str]] = UNSET
        if not isinstance(self.attached_roles, Unset):
            attached_roles = self.attached_roles

        created_at = self.created_at

        created_by = self.created_by

        identifier = self.identifier

        mapping_discriminator: Union[Unset, str] = UNSET
        if not isinstance(self.mapping_discriminator, Unset):
            mapping_discriminator = self.mapping_discriminator.value

        max_docs_per_project = self.max_docs_per_project

        max_projects = self.max_projects

        max_projects_per_user = self.max_projects_per_user

        modified_at = self.modified_at

        modified_by = self.modified_by

        system_attached_roles: Union[Unset, list[str]] = UNSET
        if not isinstance(self.system_attached_roles, Unset):
            system_attached_roles = self.system_attached_roles

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "label": label,
                "loginAllowed": login_allowed,
                "maxUsers": max_users,
                "name": name,
            }
        )
        if attached_roles is not UNSET:
            field_dict["attachedRoles"] = attached_roles
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if created_by is not UNSET:
            field_dict["createdBy"] = created_by
        if identifier is not UNSET:
            field_dict["identifier"] = identifier
        if mapping_discriminator is not UNSET:
            field_dict["mappingDiscriminator"] = mapping_discriminator
        if max_docs_per_project is not UNSET:
            field_dict["maxDocsPerProject"] = max_docs_per_project
        if max_projects is not UNSET:
            field_dict["maxProjects"] = max_projects
        if max_projects_per_user is not UNSET:
            field_dict["maxProjectsPerUser"] = max_projects_per_user
        if modified_at is not UNSET:
            field_dict["modifiedAt"] = modified_at
        if modified_by is not UNSET:
            field_dict["modifiedBy"] = modified_by
        if system_attached_roles is not UNSET:
            field_dict["systemAttachedRoles"] = system_attached_roles

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        label = d.pop("label")

        login_allowed = d.pop("loginAllowed")

        max_users = d.pop("maxUsers")

        name = d.pop("name")

        attached_roles = cast(list[str], d.pop("attachedRoles", UNSET))

        created_at = d.pop("createdAt", UNSET)

        created_by = d.pop("createdBy", UNSET)

        identifier = d.pop("identifier", UNSET)

        _mapping_discriminator = d.pop("mappingDiscriminator", UNSET)
        mapping_discriminator: Union[Unset, GroupDescMappingDiscriminator]
        if isinstance(_mapping_discriminator, Unset):
            mapping_discriminator = UNSET
        else:
            mapping_discriminator = GroupDescMappingDiscriminator(
                _mapping_discriminator
            )

        max_docs_per_project = d.pop("maxDocsPerProject", UNSET)

        max_projects = d.pop("maxProjects", UNSET)

        max_projects_per_user = d.pop("maxProjectsPerUser", UNSET)

        modified_at = d.pop("modifiedAt", UNSET)

        modified_by = d.pop("modifiedBy", UNSET)

        system_attached_roles = cast(list[str], d.pop("systemAttachedRoles", UNSET))

        group_desc = cls(
            label=label,
            login_allowed=login_allowed,
            max_users=max_users,
            name=name,
            attached_roles=attached_roles,
            created_at=created_at,
            created_by=created_by,
            identifier=identifier,
            mapping_discriminator=mapping_discriminator,
            max_docs_per_project=max_docs_per_project,
            max_projects=max_projects,
            max_projects_per_user=max_projects_per_user,
            modified_at=modified_at,
            modified_by=modified_by,
            system_attached_roles=system_attached_roles,
        )

        return group_desc



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.output_params import OutputParams
    from ..models.question_answering_params import QuestionAnsweringParams
    from ..models.search_params import SearchParams


T = TypeVar("T", bound="SearchRequest")


@_attrs_define
class SearchRequest:
    """Search request

    Attributes:
        output (Union[Unset, OutputParams]): Search output parameters
        question_answering (Union[Unset, QuestionAnsweringParams]): Question answering parameters
        search (Union[Unset, SearchParams]): Search parameters
    """

    output: Union[Unset, "OutputParams"] = UNSET
    question_answering: Union[Unset, "QuestionAnsweringParams"] = UNSET
    search: Union[Unset, "SearchParams"] = UNSET

    def to_dict(self) -> dict[str, Any]:
        output: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.output, Unset):
            output = self.output.to_dict()

        question_answering: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.question_answering, Unset):
            question_answering = self.question_answering.to_dict()

        search: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.search, Unset):
            search = self.search.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if output is not UNSET:
            field_dict["output"] = output
        if question_answering is not UNSET:
            field_dict["questionAnswering"] = question_answering
        if search is not UNSET:
            field_dict["search"] = search

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.output_params import OutputParams
        from ..models.question_answering_params import QuestionAnsweringParams
        from ..models.search_params import SearchParams

        d = dict(src_dict)
        _output = d.pop("output", UNSET)
        output: Union[Unset, OutputParams]
        if isinstance(_output, Unset):
            output = UNSET
        else:
            output = OutputParams.from_dict(_output)

        _question_answering = d.pop("questionAnswering", UNSET)
        question_answering: Union[Unset, QuestionAnsweringParams]
        if isinstance(_question_answering, Unset):
            question_answering = UNSET
        else:
            question_answering = QuestionAnsweringParams.from_dict(_question_answering)

        _search = d.pop("search", UNSET)
        search: Union[Unset, SearchParams]
        if isinstance(_search, Unset):
            search = UNSET
        else:
            search = SearchParams.from_dict(_search)

        search_request = cls(
            output=output,
            question_answering=question_answering,
            search=search,
        )

        return search_request



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, cast

from attrs import define as _attrs_define

if TYPE_CHECKING:
    from ..models.batch_errors import BatchErrors
    from ..models.ownership_change import OwnershipChange
    from ..models.project_user_share import ProjectUserShare


T = TypeVar("T", bound="BatchChownChmodResult")


@_attrs_define
class BatchChownChmodResult:
    """
    Attributes:
        errors (BatchErrors):
        non_chowned_projects (list[str]):
        ownership_changes (list['OwnershipChange']):
        project_user_shares (list['ProjectUserShare']):
    """

    errors: "BatchErrors"
    non_chowned_projects: list[str]
    ownership_changes: list["OwnershipChange"]
    project_user_shares: list["ProjectUserShare"]

    def to_dict(self) -> dict[str, Any]:
        errors = self.errors.to_dict()

        non_chowned_projects = self.non_chowned_projects

        ownership_changes = []
        for ownership_changes_item_data in self.ownership_changes:
            ownership_changes_item = ownership_changes_item_data.to_dict()
            ownership_changes.append(ownership_changes_item)

        project_user_shares = []
        for project_user_shares_item_data in self.project_user_shares:
            project_user_shares_item = project_user_shares_item_data.to_dict()
            project_user_shares.append(project_user_shares_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "errors": errors,
                "nonChownedProjects": non_chowned_projects,
                "ownershipChanges": ownership_changes,
                "projectUserShares": project_user_shares,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.batch_errors import BatchErrors
        from ..models.ownership_change import OwnershipChange
        from ..models.project_user_share import ProjectUserShare

        d = dict(src_dict)
        errors = BatchErrors.from_dict(d.pop("errors"))

        non_chowned_projects = cast(list[str], d.pop("nonChownedProjects"))

        ownership_changes = []
        _ownership_changes = d.pop("ownershipChanges")
        for ownership_changes_item_data in _ownership_changes:
            ownership_changes_item = OwnershipChange.from_dict(
                ownership_changes_item_data
            )

            ownership_changes.append(ownership_changes_item)

        project_user_shares = []
        _project_user_shares = d.pop("projectUserShares")
        for project_user_shares_item_data in _project_user_shares:
            project_user_shares_item = ProjectUserShare.from_dict(
                project_user_shares_item_data
            )

            project_user_shares.append(project_user_shares_item)

        batch_chown_chmod_result = cls(
            errors=errors,
            non_chowned_projects=non_chowned_projects,
            ownership_changes=ownership_changes,
            project_user_shares=project_user_shares,
        )

        return batch_chown_chmod_result



from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.project_bean import ProjectBean
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    compute_metrics: Union[Unset, bool] = False,
    compute_owners: Union[Unset, bool] = False,
    compute_engines: Union[Unset, bool] = False,
    estimated_counts: Union[Unset, bool] = False,
    group_name: Union[Unset, str] = UNSET,
    username: Union[Unset, str] = UNSET,
) -> dict[str, Any]:

    params: dict[str, Any] = {}

    params["computeMetrics"] = compute_metrics

    params["computeOwners"] = compute_owners

    params["computeEngines"] = compute_engines

    params["estimatedCounts"] = estimated_counts

    params["groupName"] = group_name

    params["username"] = username

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/projects",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[list["ProjectBean"]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for componentsschemas_project_bean_array_item_data in _response_200:
            componentsschemas_project_bean_array_item = ProjectBean.from_dict(
                componentsschemas_project_bean_array_item_data
            )

            response_200.append(componentsschemas_project_bean_array_item)

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[list["ProjectBean"]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    compute_metrics: Union[Unset, bool] = False,
    compute_owners: Union[Unset, bool] = False,
    compute_engines: Union[Unset, bool] = False,
    estimated_counts: Union[Unset, bool] = False,
    group_name: Union[Unset, str] = UNSET,
    username: Union[Unset, str] = UNSET,
) -> Response[list["ProjectBean"]]:
    """Get projects

    Args:
        compute_metrics (Union[Unset, bool]):  Default: False.
        compute_owners (Union[Unset, bool]):  Default: False.
        compute_engines (Union[Unset, bool]):  Default: False.
        estimated_counts (Union[Unset, bool]):  Default: False.
        group_name (Union[Unset, str]):
        username (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[list['ProjectBean']]
    """

    kwargs = _get_kwargs(
        compute_metrics=compute_metrics,
        compute_owners=compute_owners,
        compute_engines=compute_engines,
        estimated_counts=estimated_counts,
        group_name=group_name,
        username=username,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    compute_metrics: Union[Unset, bool] = False,
    compute_owners: Union[Unset, bool] = False,
    compute_engines: Union[Unset, bool] = False,
    estimated_counts: Union[Unset, bool] = False,
    group_name: Union[Unset, str] = UNSET,
    username: Union[Unset, str] = UNSET,
) -> Optional[list["ProjectBean"]]:
    """Get projects

    Args:
        compute_metrics (Union[Unset, bool]):  Default: False.
        compute_owners (Union[Unset, bool]):  Default: False.
        compute_engines (Union[Unset, bool]):  Default: False.
        estimated_counts (Union[Unset, bool]):  Default: False.
        group_name (Union[Unset, str]):
        username (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        list['ProjectBean']
    """

    return sync_detailed(
        client=client,
        compute_metrics=compute_metrics,
        compute_owners=compute_owners,
        compute_engines=compute_engines,
        estimated_counts=estimated_counts,
        group_name=group_name,
        username=username,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    compute_metrics: Union[Unset, bool] = False,
    compute_owners: Union[Unset, bool] = False,
    compute_engines: Union[Unset, bool] = False,
    estimated_counts: Union[Unset, bool] = False,
    group_name: Union[Unset, str] = UNSET,
    username: Union[Unset, str] = UNSET,
) -> Response[list["ProjectBean"]]:
    """Get projects

    Args:
        compute_metrics (Union[Unset, bool]):  Default: False.
        compute_owners (Union[Unset, bool]):  Default: False.
        compute_engines (Union[Unset, bool]):  Default: False.
        estimated_counts (Union[Unset, bool]):  Default: False.
        group_name (Union[Unset, str]):
        username (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[list['ProjectBean']]
    """

    kwargs = _get_kwargs(
        compute_metrics=compute_metrics,
        compute_owners=compute_owners,
        compute_engines=compute_engines,
        estimated_counts=estimated_counts,
        group_name=group_name,
        username=username,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    compute_metrics: Union[Unset, bool] = False,
    compute_owners: Union[Unset, bool] = False,
    compute_engines: Union[Unset, bool] = False,
    estimated_counts: Union[Unset, bool] = False,
    group_name: Union[Unset, str] = UNSET,
    username: Union[Unset, str] = UNSET,
) -> Optional[list["ProjectBean"]]:
    """Get projects

    Args:
        compute_metrics (Union[Unset, bool]):  Default: False.
        compute_owners (Union[Unset, bool]):  Default: False.
        compute_engines (Union[Unset, bool]):  Default: False.
        estimated_counts (Union[Unset, bool]):  Default: False.
        group_name (Union[Unset, str]):
        username (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        list['ProjectBean']
    """

    return (
        await asyncio_detailed(
            client=client,
            compute_metrics=compute_metrics,
            compute_owners=compute_owners,
            compute_engines=compute_engines,
            estimated_counts=estimated_counts,
            group_name=group_name,
            username=username,
        )
    ).parsed



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..models.annotation_creation_mode import AnnotationCreationMode
from ..models.annotation_status import AnnotationStatus
from ..types import UNSET, Unset

T = TypeVar("T", bound="Annotation")


@_attrs_define
class Annotation:
    """A document annotation

    Attributes:
        document_identifier (str): The document identifier
        end (int): End offset in document
        label_name (str): The label name
        start (int): Start offset in document
        text (str): Covered text
        creation_mode (Union[Unset, AnnotationCreationMode]): Creation mode
        status (Union[Unset, AnnotationStatus]): Status of the annotation
    """

    document_identifier: str
    end: int
    label_name: str
    start: int
    text: str
    creation_mode: Union[Unset, AnnotationCreationMode] = UNSET
    status: Union[Unset, AnnotationStatus] = UNSET

    def to_dict(self) -> dict[str, Any]:
        document_identifier = self.document_identifier

        end = self.end

        label_name = self.label_name

        start = self.start

        text = self.text

        creation_mode: Union[Unset, str] = UNSET
        if not isinstance(self.creation_mode, Unset):
            creation_mode = self.creation_mode.value

        status: Union[Unset, str] = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.value

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "documentIdentifier": document_identifier,
                "end": end,
                "labelName": label_name,
                "start": start,
                "text": text,
            }
        )
        if creation_mode is not UNSET:
            field_dict["creationMode"] = creation_mode
        if status is not UNSET:
            field_dict["status"] = status

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        document_identifier = d.pop("documentIdentifier")

        end = d.pop("end")

        label_name = d.pop("labelName")

        start = d.pop("start")

        text = d.pop("text")

        _creation_mode = d.pop("creationMode", UNSET)
        creation_mode: Union[Unset, AnnotationCreationMode]
        if isinstance(_creation_mode, Unset):
            creation_mode = UNSET
        else:
            creation_mode = AnnotationCreationMode(_creation_mode)

        _status = d.pop("status", UNSET)
        status: Union[Unset, AnnotationStatus]
        if isinstance(_status, Unset):
            status = UNSET
        else:
            status = AnnotationStatus(_status)

        annotation = cls(
            document_identifier=document_identifier,
            end=end,
            label_name=label_name,
            start=start,
            text=text,
            creation_mode=creation_mode,
            status=status,
        )

        return annotation



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..models.question_answering_params_language_detection import (
    QuestionAnsweringParamsLanguageDetection,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="QuestionAnsweringParams")


@_attrs_define
class QuestionAnsweringParams:
    """Question answering parameters

    Attributes:
        answer_language (Union[Unset, str]): Language of the answer (overrides languageSource)
        context (Union[Unset, bool]): Generate answer to the question Default: False.
        context_only (Union[Unset, bool]):  Default: False.
        enabled (Union[Unset, bool]): Generate answer to the question Default: False.
        generator (Union[Unset, str]): Answer generator to be used
        html (Union[Unset, bool]):  Default: False.
        language_detection (Union[Unset, QuestionAnsweringParamsLanguageDetection]): Source used to decide the language
            of the answer Default: QuestionAnsweringParamsLanguageDetection.PROJECT.
        query (Union[Unset, str]):
    """

    answer_language: Union[Unset, str] = UNSET
    context: Union[Unset, bool] = False
    context_only: Union[Unset, bool] = False
    enabled: Union[Unset, bool] = False
    generator: Union[Unset, str] = UNSET
    html: Union[Unset, bool] = False
    language_detection: Union[
        Unset, QuestionAnsweringParamsLanguageDetection
    ] = QuestionAnsweringParamsLanguageDetection.PROJECT
    query: Union[Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        answer_language = self.answer_language

        context = self.context

        context_only = self.context_only

        enabled = self.enabled

        generator = self.generator

        html = self.html

        language_detection: Union[Unset, str] = UNSET
        if not isinstance(self.language_detection, Unset):
            language_detection = self.language_detection.value

        query = self.query

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if answer_language is not UNSET:
            field_dict["answerLanguage"] = answer_language
        if context is not UNSET:
            field_dict["context"] = context
        if context_only is not UNSET:
            field_dict["contextOnly"] = context_only
        if enabled is not UNSET:
            field_dict["enabled"] = enabled
        if generator is not UNSET:
            field_dict["generator"] = generator
        if html is not UNSET:
            field_dict["html"] = html
        if language_detection is not UNSET:
            field_dict["languageDetection"] = language_detection
        if query is not UNSET:
            field_dict["query"] = query

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        answer_language = d.pop("answerLanguage", UNSET)

        context = d.pop("context", UNSET)

        context_only = d.pop("contextOnly", UNSET)

        enabled = d.pop("enabled", UNSET)

        generator = d.pop("generator", UNSET)

        html = d.pop("html", UNSET)

        _language_detection = d.pop("languageDetection", UNSET)
        language_detection: Union[Unset, QuestionAnsweringParamsLanguageDetection]
        if isinstance(_language_detection, Unset):
            language_detection = UNSET
        else:
            language_detection = QuestionAnsweringParamsLanguageDetection(
                _language_detection
            )

        query = d.pop("query", UNSET)

        question_answering_params = cls(
            answer_language=answer_language,
            context=context,
            context_only=context_only,
            enabled=enabled,
            generator=generator,
            html=html,
            language_detection=language_detection,
            query=query,
        )

        return question_answering_params



from collections.abc import Mapping
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="DefaultProcessorContext")


@_attrs_define
class DefaultProcessorContext:
    """
    Attributes:
        language (Union[Unset, str]): language context
        nature (Union[Unset, str]): nature context
    """

    language: Union[Unset, str] = UNSET
    nature: Union[Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        language = self.language

        nature = self.nature

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if language is not UNSET:
            field_dict["language"] = language
        if nature is not UNSET:
            field_dict["nature"] = nature

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        language = d.pop("language", UNSET)

        nature = d.pop("nature", UNSET)

        default_processor_context = cls(
            language=language,
            nature=nature,
        )

        return default_processor_context



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define

if TYPE_CHECKING:
    from ..models.term_hit_term import TermHitTerm


T = TypeVar("T", bound="TermHit")


@_attrs_define
class TermHit:
    """
    Attributes:
        score (float):
        term (TermHitTerm):
    """

    score: float
    term: "TermHitTerm"

    def to_dict(self) -> dict[str, Any]:
        score = self.score

        term = self.term.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "score": score,
                "term": term,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.term_hit_term import TermHitTerm

        d = dict(src_dict)
        score = d.pop("score")

        term = TermHitTerm.from_dict(d.pop("term"))

        term_hit = cls(
            score=score,
            term=term,
        )

        return term_hit



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="MessageAudience")


@_attrs_define
class MessageAudience:
    """
    Attributes:
        group_names (Union[Unset, list[str]]):
        usernames (Union[Unset, list[str]]):
    """

    group_names: Union[Unset, list[str]] = UNSET
    usernames: Union[Unset, list[str]] = UNSET

    def to_dict(self) -> dict[str, Any]:
        group_names: Union[Unset, list[str]] = UNSET
        if not isinstance(self.group_names, Unset):
            group_names = self.group_names

        usernames: Union[Unset, list[str]] = UNSET
        if not isinstance(self.usernames, Unset):
            usernames = self.usernames

        field_dict: dict[str, Any] = {}
        field_dict.update({})
        if group_names is not UNSET:
            field_dict["groupNames"] = group_names
        if usernames is not UNSET:
            field_dict["usernames"] = usernames

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        group_names = cast(list[str], d.pop("groupNames", UNSET))

        usernames = cast(list[str], d.pop("usernames", UNSET))

        message_audience = cls(
            group_names=group_names,
            usernames=usernames,
        )

        return message_audience



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.theme_config import ThemeConfig


T = TypeVar("T", bound="Theme")


@_attrs_define
class Theme:
    """
    Attributes:
        config (ThemeConfig):
        id (str):
        label (str):
        created_at (Union[Unset, str]):
        created_by (Union[Unset, str]):
        modified_at (Union[Unset, str]):
        modified_by (Union[Unset, str]):
    """

    config: "ThemeConfig"
    id: str
    label: str
    created_at: Union[Unset, str] = UNSET
    created_by: Union[Unset, str] = UNSET
    modified_at: Union[Unset, str] = UNSET
    modified_by: Union[Unset, str] = UNSET

    def to_dict(self) -> dict[str, Any]:
        config = self.config.to_dict()

        id = self.id

        label = self.label

        created_at = self.created_at

        created_by = self.created_by

        modified_at = self.modified_at

        modified_by = self.modified_by

        field_dict: dict[str, Any] = {}
        field_dict.update(
            {
                "config": config,
                "id": id,
                "label": label,
            }
        )
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if created_by is not UNSET:
            field_dict["createdBy"] = created_by
        if modified_at is not UNSET:
            field_dict["modifiedAt"] = modified_at
        if modified_by is not UNSET:
            field_dict["modifiedBy"] = modified_by

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.theme_config import ThemeConfig

        d = dict(src_dict)
        config = ThemeConfig.from_dict(d.pop("config"))

        id = d.pop("id")

        label = d.pop("label")

        created_at = d.pop("createdAt", UNSET)

        created_by = d.pop("createdBy", UNSET)

        modified_at = d.pop("modifiedAt", UNSET)

        modified_by = d.pop("modifiedBy", UNSET)

        theme = cls(
            config=config,
            id=id,
            label=label,
            created_at=created_at,
            created_by=created_by,
            modified_at=modified_at,
            modified_by=modified_by,
        )

        return theme
